import React from 'react'

function formatMoney(number, places, symbol, thousand, decimal) {
  number = number || 0;
  places = !isNaN(places = Math.abs(places)) ? places : 2;
  symbol = symbol !== undefined ? symbol : "￥";
  thousand = thousand || ",";
  decimal = decimal || ".";
  var negative = number < 0 ? "-" : "",
    i = parseInt(number = Math.abs(+number || 0).toFixed(places), 10) + "",
    j = (j = i.length) > 3 ? j % 3 : 0;
  return symbol + negative + (j ? i.substr(0, j) + thousand : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + thousand) + (places ? decimal + Math.abs(number - i).toFixed(places).slice(2) : "");
}

const NumberView = (props) => {

  const { value, formatter, decimalDigits } = props

  const formatterFn = (value) => {
    if (value) {
      if (formatter === '${百分比}') {
        return `${value}%`
      } else if (formatter === '${货币}') {
        return formatMoney(Number(value), Number(decimalDigits))
      } else if (formatter === '${整数}') {
        return `${parseInt(value)}`
      } else if (formatter === '${正整数}') {
        return `${Math.max(0, parseInt(value))}`
      } if (formatter === '${小数}') {
        return Number(value).toFixed(Number(decimalDigits))
      } else if (formatter === '${科学计数法}') {
        return Number(value).toExponential()
      } else if (formatter) {
        return `${value}${formatter}`
      }
    }
    return value
  }

  return (
    <div>{formatterFn(value)}</div>
  )

}

export default NumberView